@@ -29,7 +29,7 @@ from dataclasses import dataclass
 from io import BytesIO
 from operator import attrgetter
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, cast
 from warnings import warn
 
 from lxml import etree
@@ -37,7 +37,7 @@ from typing_extensions import Self
 
 from .attribute_register import XML2HTML_FORMATTER
 from .docx_context import collect_numFmts, collect_rels
-from .docx_text import get_text
+from .docx_text import TablesList, get_text, new_depth_collector
 from .merge_runs import merge_elems
 
 if TYPE_CHECKING:
@@ -45,6 +45,8 @@ if TYPE_CHECKING:
 
     from lxml.etree import _Element as EtreeElement  # type: ignore
 
+    from .depth_collector import DepthCollector
+
 CONTENT_FILE_TYPES = {"officeDocument", "header", "footer", "footnotes", "endnotes"}
 
 
@@ -89,6 +91,7 @@ class File:
         self.__rels_path: None | str = None
         self.__rels: None | dict[str, str] = None
         self.__root_element: None | EtreeElement = None
+        self.__depth_collector: None | DepthCollector = None
 
     def __repr__(self) -> str:
         """File with self.path
@@ -223,13 +226,24 @@ class File:
         self.__root_element = root
         return self.__root_element
 
+    @property
+    def depth_collector(self) -> DepthCollector:
+        """DepthCollector instance for this file.
+
+        :return: DepthCollector instance for this file.
+
+        The DepthCollector instance will be used to extract text from the file.
+        """
+        self.__depth_collector = self.__depth_collector or new_depth_collector(self)
+        return self.__depth_collector
+
     @property
     def content(self) -> list[list[list[list[str]]]]:
         """Text extracted into a 5-layer-deep nested list of strings.
 
         :return: Text extracted into a 5-layer-deep nested list of strings.
         """
-        return get_text(self)
+        return self.get_content()
 
     def get_content(
         self, root: EtreeElement | None = None
@@ -241,6 +255,8 @@ class File:
             If root is not given, return full content of file.
         :return: Text extracted into a 5-layer-deep nested list of strings.
         """
+        if root is None:
+            return cast(TablesList, self.depth_collector.tree)
         return get_text(self, root)
 
 
@@ -339,6 +355,19 @@ class DocxReader:
         self.__files = files
         return self.__files
 
+    @property
+    def comments(self) -> list[EtreeElement]:
+        """
+        Comments from the document.
+
+        :return: Comments from the document.
+        """
+        try:
+            comment_file = self.file_of_type("comments")
+        except KeyError:
+            return []
+        return list(comment_file.root_element)
+
     @property
     def numId2numFmts(self) -> dict[str, list[str]]:
         """
@@ -388,7 +417,7 @@ class DocxReader:
         File instances with attrib Type='http://.../type_'
 
         :param type_: this package looks for any of
-            ("header", "officeDocument", "footer", "footnotes", "endnotes")
+            ("header", "officeDocument", "footer", "footnotes", "endnotes", "comments")
             You can try others. If argument is None (default), returns all content file
             types.
         :return: File instances of the requested type, sorted by path
